@@ -24,7 +24,7 @@ from vrchatapi.model.current_user import CurrentUser
 from vrchatapi.model.deployment_group import DeploymentGroup
 from vrchatapi.model.developer_type import DeveloperType
 from vrchatapi.model.download_url_list import DownloadURLList
-from vrchatapi.model.dynamic_world_row import DynamicWorldRow
+from vrchatapi.model.dynamic_content_row import DynamicContentRow
 from vrchatapi.model.error import Error
 from vrchatapi.model.favorite import Favorite
 from vrchatapi.model.favorite_group import FavoriteGroup
@@ -41,15 +41,25 @@ from vrchatapi.model.file_version import FileVersion
 from vrchatapi.model.file_version_upload_status import FileVersionUploadStatus
 from vrchatapi.model.finish_file_data_upload_request import FinishFileDataUploadRequest
 from vrchatapi.model.friend_status import FriendStatus
-from vrchatapi.model.inline_response404 import InlineResponse404
+from vrchatapi.model.info_push import InfoPush
+from vrchatapi.model.info_push_data import InfoPushData
+from vrchatapi.model.info_push_data_article import InfoPushDataArticle
+from vrchatapi.model.info_push_data_article_content import InfoPushDataArticleContent
+from vrchatapi.model.info_push_data_clickable import InfoPushDataClickable
 from vrchatapi.model.instance import Instance
 from vrchatapi.model.instance_id import InstanceID
 from vrchatapi.model.instance_platforms import InstancePlatforms
+from vrchatapi.model.instance_type import InstanceType
 from vrchatapi.model.invite_message import InviteMessage
 from vrchatapi.model.invite_message_id import InviteMessageID
 from vrchatapi.model.invite_message_type import InviteMessageType
 from vrchatapi.model.invite_request import InviteRequest
 from vrchatapi.model.invite_response import InviteResponse
+from vrchatapi.model.license import License
+from vrchatapi.model.license_action import LicenseAction
+from vrchatapi.model.license_group import LicenseGroup
+from vrchatapi.model.license_group_id import LicenseGroupID
+from vrchatapi.model.license_type import LicenseType
 from vrchatapi.model.limited_unity_package import LimitedUnityPackage
 from vrchatapi.model.limited_user import LimitedUser
 from vrchatapi.model.limited_world import LimitedWorld
@@ -64,10 +74,19 @@ from vrchatapi.model.player_moderation import PlayerModeration
 from vrchatapi.model.player_moderation_id import PlayerModerationID
 from vrchatapi.model.player_moderation_type import PlayerModerationType
 from vrchatapi.model.public_announcement import PublicAnnouncement
+from vrchatapi.model.region import Region
 from vrchatapi.model.release_status import ReleaseStatus
 from vrchatapi.model.response import Response
+from vrchatapi.model.subscription import Subscription
+from vrchatapi.model.subscription_period import SubscriptionPeriod
 from vrchatapi.model.success import Success
 from vrchatapi.model.tag import Tag
+from vrchatapi.model.transaction import Transaction
+from vrchatapi.model.transaction_agreement import TransactionAgreement
+from vrchatapi.model.transaction_id import TransactionID
+from vrchatapi.model.transaction_status import TransactionStatus
+from vrchatapi.model.transaction_steam_info import TransactionSteamInfo
+from vrchatapi.model.transaction_steam_wallet_info import TransactionSteamWalletInfo
 from vrchatapi.model.two_factor_auth_code import TwoFactorAuthCode
 from vrchatapi.model.unity_package import UnityPackage
 from vrchatapi.model.unity_package_id import UnityPackageID
@@ -80,6 +99,7 @@ from vrchatapi.model.user import User
 from vrchatapi.model.user_exists import UserExists
 from vrchatapi.model.user_state import UserState
 from vrchatapi.model.user_status import UserStatus
+from vrchatapi.model.user_subscription import UserSubscription
 from vrchatapi.model.verify2_fa_result import Verify2FAResult
 from vrchatapi.model.verify_auth_token_result import VerifyAuthTokenResult
 from vrchatapi.model.world import World
